import { RequestOptionsFactory } from '@wix/sdk-types';
/** Creates a custom field. */
export declare function createCustomField(payload: object): RequestOptionsFactory<any>;
/** Retrieves a custom field by ID. */
export declare function getCustomField(payload: object): RequestOptionsFactory<any>;
/**
 * Retrieves a list of custom fields and fields provided by Members Area, given the provided paging.
 *
 * The fields are ordered by section in the following sequence:
 * - `GENERAL`
 * - `DISPLAY_INFO`
 * - `SOCIAL`
 *
 * The fields in the same section are ordered by the field creation date.
 *
 * To change the order of fields in sections, call [Update Custom Fields Order](https://dev.wix.com/docs/rest/crm/members-contacts/members/custom-fields/custom-fields/update-custom-fields-order).
 */
export declare function listCustomFields(payload: object): RequestOptionsFactory<any>;
/**
 * Updates a custom field.
 *
 * For custom fields you can update the following fields: `name`, `defaultPrivacy`, `socialType`.
 *
 * For fields provided by the Members Area you can only update the `defaultPrivacy` field.
 */
export declare function updateCustomField(payload: object): RequestOptionsFactory<any>;
/**
 * Deletes a custom field.
 *
 * The related custom field in the contacts list is also be removed.
 */
export declare function deleteCustomField(payload: object): RequestOptionsFactory<any>;
/**
 * Hides a custom field.
 *
 * The hidden field is removed from the members custom fields list, yet it's still available as a suggested field to add later.
 *
 * The related contacts custom field will still be available in the contacts list.
 */
export declare function hideCustomField(payload: object): RequestOptionsFactory<any>;
/** Updates the custom fields order in a section. */
export declare function updateCustomFieldsOrder(payload: object): RequestOptionsFactory<any>;
