import { HttpClient } from '@wix/sdk-types';
import { CustomField, CustomFieldNonNullableFields, GetCustomFieldResponse, GetCustomFieldResponseNonNullableFields, ListCustomFieldsOptions, ListCustomFieldsResponse, ListCustomFieldsResponseNonNullableFields, UpdateCustomField, UpdateCustomFieldsOrderOptions, UpdateCustomFieldsOrderResponse, UpdateCustomFieldsOrderResponseNonNullableFields } from './members-v1-custom-field-custom-field.universal.js';
export declare const __metadata: {
    PACKAGE_NAME: string;
};
export declare function createCustomField(httpClient: HttpClient): CreateCustomFieldSignature;
interface CreateCustomFieldSignature {
    /**
     * Creates a custom field.
     * @param - Custom field to create.
     * @returns Custom field.
     */
    (field: CustomField): Promise<CustomField & CustomFieldNonNullableFields>;
}
export declare function getCustomField(httpClient: HttpClient): GetCustomFieldSignature;
interface GetCustomFieldSignature {
    /**
     * Retrieves a custom field by ID.
     * @param - Custom field ID.
     */
    (_id: string | null): Promise<GetCustomFieldResponse & GetCustomFieldResponseNonNullableFields>;
}
export declare function listCustomFields(httpClient: HttpClient): ListCustomFieldsSignature;
interface ListCustomFieldsSignature {
    /**
     * Retrieves a list of custom fields and fields provided by Members Area, given the provided paging.
     *
     * The fields are ordered by section in the following sequence:
     * - `GENERAL`
     * - `DISPLAY_INFO`
     * - `SOCIAL`
     *
     * The fields in the same section are ordered by the field creation date.
     *
     * To change the order of fields in sections, call [Update Custom Fields Order](https://dev.wix.com/docs/rest/crm/members-contacts/members/custom-fields/custom-fields/update-custom-fields-order).
     */
    (options?: ListCustomFieldsOptions | undefined): Promise<ListCustomFieldsResponse & ListCustomFieldsResponseNonNullableFields>;
}
export declare function updateCustomField(httpClient: HttpClient): UpdateCustomFieldSignature;
interface UpdateCustomFieldSignature {
    /**
     * Updates a custom field.
     *
     * For custom fields you can update the following fields: `name`, `defaultPrivacy`, `socialType`.
     *
     * For fields provided by the Members Area you can only update the `defaultPrivacy` field.
     * @param - Custom field ID.
     * @returns Updated custom field.
     */
    (_id: string | null, field: UpdateCustomField): Promise<CustomField & CustomFieldNonNullableFields>;
}
export declare function deleteCustomField(httpClient: HttpClient): DeleteCustomFieldSignature;
interface DeleteCustomFieldSignature {
    /**
     * Deletes a custom field.
     *
     * The related custom field in the contacts list is also be removed.
     * @param - ID of the custom field to delete.
     * @param - Revision number.
     */
    (_id: string | null, revision: string | null): Promise<void>;
}
export declare function hideCustomField(httpClient: HttpClient): HideCustomFieldSignature;
interface HideCustomFieldSignature {
    /**
     * Hides a custom field.
     *
     * The hidden field is removed from the members custom fields list, yet it's still available as a suggested field to add later.
     *
     * The related contacts custom field will still be available in the contacts list.
     * @param - ID of the custom field to hide.
     * @param - Revision number.
     */
    (_id: string | null, revision: string | null): Promise<void>;
}
export declare function updateCustomFieldsOrder(httpClient: HttpClient): UpdateCustomFieldsOrderSignature;
interface UpdateCustomFieldsOrderSignature {
    /**
     * Updates the custom fields order in a section.
     * @param - IDs of the custom fields to be reodered.
     */
    (fieldIds: string[], options?: UpdateCustomFieldsOrderOptions | undefined): Promise<UpdateCustomFieldsOrderResponse & UpdateCustomFieldsOrderResponseNonNullableFields>;
}
export { ActionEvent, AppliesTo, Asset, CreateCustomFieldRequest, CreateCustomFieldResponse, CreateCustomFieldResponseNonNullableFields, CustomField, CustomFieldNonNullableFields, DefaultPrivacyChanged, DeleteContext, DeleteCustomFieldRequest, DeleteCustomFieldResponse, DeleteStatus, DomainEvent, DomainEventBodyOneOf, Empty, EntityCreatedEvent, EntityDeletedEvent, EntityUpdatedEvent, GetCustomFieldRequest, GetCustomFieldResponse, GetCustomFieldResponseNonNullableFields, HideCustomFieldRequest, HideCustomFieldResponse, IdentificationData, IdentificationDataIdOneOf, IncorrectFieldTypeData, IncorrectPrivacyData, InvalidSocialTypeData, ListCustomFieldsOptions, ListCustomFieldsRequest, ListCustomFieldsResponse, ListCustomFieldsResponseNonNullableFields, MessageEnvelope, MetaSiteSpecialEvent, MetaSiteSpecialEventPayloadOneOf, Namespace, NamespaceChanged, Origin, Paging, PagingMetadata, Privacy, ReservedFieldNameNonEditable, RestoreInfo, Section, ServiceProvisioned, ServiceRemoved, SiteCreated, SiteCreatedContext, SiteDeleted, SiteHardDeleted, SiteMarkedAsTemplate, SiteMarkedAsWixSite, SitePublished, SiteRenamed, SiteTransferred, SiteUndeleted, SiteUnpublished, SocialTypeType, State, StudioAssigned, StudioUnassigned, Type, UpdateCustomField, UpdateCustomFieldRequest, UpdateCustomFieldResponse, UpdateCustomFieldResponseNonNullableFields, UpdateCustomFieldsOrderOptions, UpdateCustomFieldsOrderRequest, UpdateCustomFieldsOrderResponse, UpdateCustomFieldsOrderResponseNonNullableFields, WebhookIdentityType, } from './members-v1-custom-field-custom-field.universal.js';
