import { toURLSearchParams } from '@wix/sdk-runtime/rest-modules';
import { transformSDKTimestampToRESTTimestamp } from '@wix/sdk-runtime/transformations/timestamp';
import { transformRESTTimestampToSDKTimestamp } from '@wix/sdk-runtime/transformations/timestamp';
import { transformPaths } from '@wix/sdk-runtime/transformations/transform-paths';
import { resolveUrl } from '@wix/sdk-runtime/rest-modules';
function resolveComWixpressMembersCustomfieldsCustomFieldsUrl(opts) {
    const domainToMappings = {
        'manage._base_domain_': [
            {
                srcPath: '/_api/members/v1/custom-fields',
                destPath: '/v1/custom-fields',
            },
        ],
        _: [
            {
                srcPath: '/_api/members/v1/custom-fields',
                destPath: '/v1/custom-fields',
            },
        ],
        'www._base_domain_': [
            {
                srcPath: '/_api/members/v1/custom-fields',
                destPath: '/v1/custom-fields',
            },
        ],
        'www.wixapis.com': [
            {
                srcPath: '/members/v1/custom-fields',
                destPath: '/v1/custom-fields',
            },
        ],
        'editor-flow.wixapps.net': [
            {
                srcPath: '/_api/members/v1/custom-fields',
                destPath: '/v1/custom-fields',
            },
        ],
        'api._api_base_domain_': [
            {
                srcPath: '/members/v1/custom-fields',
                destPath: '',
            },
        ],
        'editor.wixapps.net': [
            {
                srcPath: '/_api/members/v1/custom-fields',
                destPath: '/v1/custom-fields',
            },
        ],
    };
    return resolveUrl(Object.assign(opts, { domainToMappings }));
}
const PACKAGE_NAME = '@wix/auto_sdk_members_custom-field';
/** Creates a custom field. */
export function createCustomField(payload) {
    function __createCustomField({ host }) {
        const serializedData = transformPaths(payload, [
            {
                transformFn: transformSDKTimestampToRESTTimestamp,
                paths: [{ path: 'field.createdDate' }, { path: 'field.updatedDate' }],
            },
        ]);
        const metadata = {
            entityFqdn: 'wix.members.v1.custom_field',
            method: 'POST',
            methodFqn: 'com.wixpress.members.customfields.CustomFields.CreateCustomField',
            packageName: PACKAGE_NAME,
            url: resolveComWixpressMembersCustomfieldsCustomFieldsUrl({
                protoPath: '/v1/custom-fields',
                data: serializedData,
                host,
            }),
            data: serializedData,
            transformResponse: (payload) => transformPaths(payload, [
                {
                    transformFn: transformRESTTimestampToSDKTimestamp,
                    paths: [
                        { path: 'field.createdDate' },
                        { path: 'field.updatedDate' },
                    ],
                },
            ]),
        };
        return metadata;
    }
    return __createCustomField;
}
/** Retrieves a custom field by ID. */
export function getCustomField(payload) {
    function __getCustomField({ host }) {
        const metadata = {
            entityFqdn: 'wix.members.v1.custom_field',
            method: 'GET',
            methodFqn: 'com.wixpress.members.customfields.CustomFields.GetCustomField',
            packageName: PACKAGE_NAME,
            url: resolveComWixpressMembersCustomfieldsCustomFieldsUrl({
                protoPath: '/v1/custom-fields/{id}',
                data: payload,
                host,
            }),
            params: toURLSearchParams(payload),
            transformResponse: (payload) => transformPaths(payload, [
                {
                    transformFn: transformRESTTimestampToSDKTimestamp,
                    paths: [
                        { path: 'field.createdDate' },
                        { path: 'field.updatedDate' },
                    ],
                },
            ]),
        };
        return metadata;
    }
    return __getCustomField;
}
/**
 * Retrieves a list of custom fields and fields provided by Members Area, given the provided paging.
 *
 * The fields are ordered by section in the following sequence:
 * - `GENERAL`
 * - `DISPLAY_INFO`
 * - `SOCIAL`
 *
 * The fields in the same section are ordered by the field creation date.
 *
 * To change the order of fields in sections, call [Update Custom Fields Order](https://dev.wix.com/docs/rest/crm/members-contacts/members/custom-fields/custom-fields/update-custom-fields-order).
 */
export function listCustomFields(payload) {
    function __listCustomFields({ host }) {
        const metadata = {
            entityFqdn: 'wix.members.v1.custom_field',
            method: 'GET',
            methodFqn: 'com.wixpress.members.customfields.CustomFields.ListCustomFields',
            packageName: PACKAGE_NAME,
            url: resolveComWixpressMembersCustomfieldsCustomFieldsUrl({
                protoPath: '/v1/custom-fields',
                data: payload,
                host,
            }),
            params: toURLSearchParams(payload),
            transformResponse: (payload) => transformPaths(payload, [
                {
                    transformFn: transformRESTTimestampToSDKTimestamp,
                    paths: [
                        { path: 'fields.createdDate' },
                        { path: 'fields.updatedDate' },
                    ],
                },
            ]),
        };
        return metadata;
    }
    return __listCustomFields;
}
/**
 * Updates a custom field.
 *
 * For custom fields you can update the following fields: `name`, `defaultPrivacy`, `socialType`.
 *
 * For fields provided by the Members Area you can only update the `defaultPrivacy` field.
 */
export function updateCustomField(payload) {
    function __updateCustomField({ host }) {
        const serializedData = transformPaths(payload, [
            {
                transformFn: transformSDKTimestampToRESTTimestamp,
                paths: [{ path: 'field.createdDate' }, { path: 'field.updatedDate' }],
            },
        ]);
        const metadata = {
            entityFqdn: 'wix.members.v1.custom_field',
            method: 'PATCH',
            methodFqn: 'com.wixpress.members.customfields.CustomFields.UpdateCustomField',
            packageName: PACKAGE_NAME,
            url: resolveComWixpressMembersCustomfieldsCustomFieldsUrl({
                protoPath: '/v1/custom-fields/{field.id}',
                data: serializedData,
                host,
            }),
            data: serializedData,
            transformResponse: (payload) => transformPaths(payload, [
                {
                    transformFn: transformRESTTimestampToSDKTimestamp,
                    paths: [
                        { path: 'field.createdDate' },
                        { path: 'field.updatedDate' },
                    ],
                },
            ]),
        };
        return metadata;
    }
    return __updateCustomField;
}
/**
 * Deletes a custom field.
 *
 * The related custom field in the contacts list is also be removed.
 */
export function deleteCustomField(payload) {
    function __deleteCustomField({ host }) {
        const metadata = {
            entityFqdn: 'wix.members.v1.custom_field',
            method: 'DELETE',
            methodFqn: 'com.wixpress.members.customfields.CustomFields.DeleteCustomField',
            packageName: PACKAGE_NAME,
            url: resolveComWixpressMembersCustomfieldsCustomFieldsUrl({
                protoPath: '/v1/custom-fields/{id}',
                data: payload,
                host,
            }),
            params: toURLSearchParams(payload),
        };
        return metadata;
    }
    return __deleteCustomField;
}
/**
 * Hides a custom field.
 *
 * The hidden field is removed from the members custom fields list, yet it's still available as a suggested field to add later.
 *
 * The related contacts custom field will still be available in the contacts list.
 */
export function hideCustomField(payload) {
    function __hideCustomField({ host }) {
        const metadata = {
            entityFqdn: 'wix.members.v1.custom_field',
            method: 'POST',
            methodFqn: 'com.wixpress.members.customfields.CustomFields.HideCustomField',
            packageName: PACKAGE_NAME,
            url: resolveComWixpressMembersCustomfieldsCustomFieldsUrl({
                protoPath: '/v1/custom-fields/{id}/hide',
                data: payload,
                host,
            }),
            data: payload,
        };
        return metadata;
    }
    return __hideCustomField;
}
/** Updates the custom fields order in a section. */
export function updateCustomFieldsOrder(payload) {
    function __updateCustomFieldsOrder({ host }) {
        const metadata = {
            entityFqdn: 'wix.members.v1.custom_field',
            method: 'POST',
            methodFqn: 'com.wixpress.members.customfields.CustomFields.UpdateCustomFieldsOrder',
            packageName: PACKAGE_NAME,
            url: resolveComWixpressMembersCustomfieldsCustomFieldsUrl({
                protoPath: '/v1/custom-fields/order',
                data: payload,
                host,
            }),
            data: payload,
            transformResponse: (payload) => transformPaths(payload, [
                {
                    transformFn: transformRESTTimestampToSDKTimestamp,
                    paths: [
                        { path: 'fields.createdDate' },
                        { path: 'fields.updatedDate' },
                    ],
                },
            ]),
        };
        return metadata;
    }
    return __updateCustomFieldsOrder;
}
//# sourceMappingURL=members-v1-custom-field-custom-field.http.js.map